Usage
aalen(formula,data=sys.parent(),start.time=0,max.time=NULL,robust=1,
id=NULL,clusters=NULL,residuals=0,n.sim=1000,weighted.test=0,
covariance=0,resample.iid=0,deltaweight=1,silent=0)
Arguments
formula
a formula object with the response on the left of a '~' operator,
and the independent terms on the right as regressors.The response
must be a survival object as returned by the `Surv' function. Time-
invariant regressors are specified by the w
data
a data.frame with the variables.
start.time
start of observation period where estimates are computed.
max.time
end of observation period where estimates are computed.
Estimates thus computed from [start.time, max.time]. Default is max of data.
robust
to compute robust variances and construct processes for
resampling. May be set to 0 to save memory.
id
For timevarying covariates the variable must
associate each record with the id of a subject.
clusters
cluster variable for computation of robust
variances.
n.sim
number of simulations in resampling.
weighted.test
to compute a variance weighted version of the
test-processes used for testing
time-varying effects.
residuals
to returns residuals that can be used for
model validation in the function cum.residuals
covariance
to compute covariance estimates for
nonparametric terms rather than just the variances.
resample.iid
to return i.i.d. representation for
nonparametric and parametric terms.
deltaweight
uses weights to estimate semiparametric model, under
construction, default=1 is standard least squares estimates
silent
set to 1 to avoid printing of warnings for non-inverible
design-matrices for different timepoints, default is 0.