Usage
cox.aalen(formula=formula(data),data=sys.parent(),beta=NULL,Nit=10,detail=0,
start.time=0,max.time=NULL,id=NULL,clusters=NULL,n.sim=500,residuals=0,
robust=1,weighted.test=0,covariance=0,resample.iid=0,weights=NULL,rate.sim=1,
beta.fixed=0,max.clust=1000,exact.deriv=1,silent=0)
Arguments
formula
a formula object with the response on the left of a '~' operator, and
the independent terms on the right as regressors. The response must be
a survival object as returned by the `Surv' function. Terms with a
proportional effect are specified by the
data
a data.frame with the variables.
start.time
start of observation period where estimates are computed.
max.time
end of observation period where estimates are computed.
Estimates thus computed from [start.time, max.time]. Default is max of data.
robust
to compute robust variances and construct processes for
resampling. May be set to 0 to save memory.
id
For timevarying covariates the variable must
associate each record with the id of a subject.
clusters
cluster variable for computation of robust
variances.
n.sim
number of simulations in resampling.
weighted.test
to compute a variance weighted version of the
test-processes used for testing
time-varying effects.
residuals
to returns residuals that can be used for
model validation in the function cum.residuals. Estimated martingale increments (dM)
and corresponding time vector (time).
covariance
to compute covariance estimates for
nonparametric terms rather than just the variances.
resample.iid
to return i.i.d. representation for
nonparametric and parametric terms.
beta
starting value for relative risk estimates.
Nit
number of iterations for Newton-Raphson algorithm.
detail
if 0 no details is printed during iterations, if 1 details are given.
weights
weights for weighted analysis.
rate.sim
rate.sim=1 such that resampling of residuals is based on estimated
martingales and thus valid in rate case, rate.sim=0 means that resampling is based
on counting processes and thus only valid in intensity case.
beta.fixed
option for computing score process for fixed relative risk parameter
max.clust
sets the total number of i.i.d. terms in i.i.d. decompostition. This can
limit the amount of memory used by coarsening the clusters. When NULL then all clusters are used. Default is 1000 to save memory and time.
exact.deriv
if 1 then uses exact derivative in last iteration, if 2 then uses exact derivate
for all iterations, and if 0 then uses approximation for all computations and there may be a small
bias in the variance estimates. For Cox model always exact and all option
silent
if 1 then opppresses some output.